@@ -6,14 +6,16 @@
 #' @author Rafael Romero \email{rromero@@eio.upv.es}
 #' @references Romero, R, Pavia, JM, Martin, J and Romero G (2020). Assessing uncertainty of voter transitions estimated from aggregated data. Application to the 2017 French presidential election. *Journal of Applied Statistics*, 47(13-15), 2711-2736. \doi{10.1080/02664763.2020.1804842}
 #'
-#' @param votes_election1 data.frame (or matrix) of order IxJ (likely of final order IxJ-1
-#'                        in `regular` and `raw` scenarios) with the votes gained by the *J*
+#' @param votes_election1 data.frame (or matrix) of order IxJ (likely of final order Ix(J-1)
+#'                        in `regular` and `raw` scenarios when net entries are
+#'                        estimated by the function) with the votes gained by the *J*
 #'                        political options competing on election 1 (or origin) in the *I*
 #'                        territorial units considered. In general, the row marginals 
 #'                        of the *I* tables.
 #'
-#' @param votes_election2 data.frame (or matrix) of order IxK (likely of final order IxK-1
-#'                        in `regular` and `raw` scenarios) with the votes gained by
+#' @param votes_election2 data.frame (or matrix) of order IxK (likely of final order Ix(K-1)
+#'                        in `regular` and `raw` scenarios  when net exits are
+#'                        estimated by the function) with the votes gained by
 #'                        the *K* political options competing on election 2 (or destination)
 #'                        in the *I* territorial units considered. In general, the column marginals 
 #'                        of the *I* tables.
@@ -29,7 +31,7 @@
 #' @param structural_zeros Default NULL. A list of vectors of length two, indicating the election options
 #'                         for which no transfer of votes are allowed between election 1 and election 2.
 #'                         For instance, when new_and_exit_voters is set to `"regular"`,
-#'                         lphom implicitly `states structural_zeros = list(c(J, K))` in case exits and/or
+#'                         lphom implicitly states `structural_zeros = list(c(J, K))` in case exits and/or
 #'                         entries are computed because the sum by rows of `votes_election1` and
 #'                         `votes_election2` does not coincide.
 #'
@@ -40,8 +42,14 @@
 #'                printed on the screen. Default, FALSE.
 #'
 #' @param solver A character string indicating the linear programming solver to be used, only
-#'               `lp_solve` and `symphony` are allowed. By default, `lp_solve`.
-#'
+#'               `lp_solve` and `symphony` are allowed. By default, `lp_solve`. The package `Rsymphony`
+#'               needs to be installed for the option `symphony` to be used.
+#'                 
+#' @param integers.solver A character string indicating the linear programming solver to be used to approximate
+#'                        to the closest integer solution, only `symphony` and `lp_solve` are allowed.
+#'                        By default, `symphony`. The package `Rsymphony` needs to be installed for the option `symphony` 
+#'                        to be used. Only used when `integers = TRUE`. 
+#'                        
 #' @param ... Other arguments to be passed to the function. Not currently used.
 #'  
 
@@ -58,23 +66,23 @@
 #'                 In this scenario, when net exits and/or net entries are negligible (such as between 
 #'                 the first- and second-round of French Presidential elections), they are omitted in 
 #'                 the outputs.}
-#'  \item{`regular`: }{ For estimating vote transfer matrices, this value accounts for a scenario with 
+#'  \item{`regular`: }{For estimating vote transfer matrices, this value accounts for a scenario with 
 #'                 two elections elapsed at least some months where (i) the column *J* of `votes_election1` 
 #'                 corresponds to new young electors who have the right to vote for the first time and (ii)
-#'                 net exits (basically a consequence of mortality), and eventually net entries,
+#'                 net exits (basically a consequence of mortality), and maybe other additional net entries,
 #'                 are computed according equation (7) of Romero et al. (2020), and (iii) we
 #'                 assume net exits affect equally all the first *J-1* options of election 1,
 #'                 hence (8) and (9) constraints of Romero et al. (2020) are imposed.}
-#'  \item{`simultaneous`: }{ This is the value to be used in a classical ecological inference problems, 
+#'  \item{`simultaneous`: }{This is the value to be used in a classical ecological inference problems, 
 #'                such as for racial voting, and in a scenario with two simultaneous elections. 
 #'                In this scenario, the sum by rows of `votes_election1` and `votes_election2` must coincide. 
 #'                Constraints defined by equations (8) and (9) of Romero et al. (2020) are not included in 
 #'                the model.}
 #'  \item{`full`: }{This value accounts for a scenario with two elections elapsed at least some
-#'                months, where: (i) the column *J-1* of votes_election1 totals new young
+#'                months, where: (i) the column *J-1* of `votes_election1` totals new young
 #'                electors that have the right to vote for the first time; (ii) the column *J*
-#'                of votes_election1 measures new immigrants that have the right to vote; and
-#'                (iii) the column *K* of votes_election2 corresponds to total exits of the census
+#'                of `votes_election1` measures new immigrants that have the right to vote; and
+#'                (iii) the column *K* of `votes_election2` corresponds to total exits of the census
 #'                lists (due to death or emigration). In this scenario, the sum by rows of
 #'                `votes_election1` and `votes_election2` must agree and constraints (8)
 #'                and (9) of Romero et al. (2020) are imposed.}
@@ -107,7 +115,6 @@
 #' @examples
 #' lphom(France2017P[, 1:8] , France2017P[, 9:12], new_and_exit_voters= "raw")
 #
-#' @importFrom Rsymphony Rsymphony_solve_LP
 #' @importFrom lpSolve lp
 #
 lphom <- function(votes_election1,
@@ -117,6 +124,7 @@ lphom <- function(votes_election1,
                   integers = FALSE,
                   verbose = FALSE,
                   solver = "lp_solve",
+                  integers.solver = "symphony",
                   ...){
 
 # Loading package lpSolve
@@ -126,11 +134,11 @@ lphom <- function(votes_election1,
   argg <- c(as.list(environment()), list(...))
   integers <- test_integers(argg)
   
-  
   # inputs
   inputs <- list("votes_election1" = votes_election1, "votes_election2" = votes_election2,
                  "new_and_exit_voters" = new_and_exit_voters[1], "structural_zeros" = structural_zeros,
-                 "integers" = integers, "verbose" = verbose, "solver" = solver)
+                 "integers" = integers, "verbose" = verbose, "solver" = solver,
+                 "integers.solver" = integers.solver)
 
   # Data conditions
   x <- as.matrix(votes_election1)
@@ -153,6 +161,14 @@ lphom <- function(votes_election1,
   if (min(x,y) < 0) stop('Negative values for voters (electors) are not allowed')
   if (!(solver %in% c("symphony", "lp_solve")))
     stop('Only "symponhy", "lp_solve" are allowed as solvers')
+  if (!(integers.solver %in% c("symphony", "lp_solve")))
+    stop('Only "symponhy", "lp_solve" are allowed as solvers')
+  
+  if (integers.solver == "lp_solve"){
+    dec2counts <- dec2counts_lp
+  } else {
+    dec2counts <- dec2counts_symphony
+  }
 
   # Data preparation
   net_entries = net_exits = TRUE
