@@ -24,8 +24,14 @@
 #'                 Default, FALSE.
 #'
 #' @param solver A character string indicating the linear programming solver to be used, only
-#'               `lp_solve` and `symphony` are allowed. By default, `lp_solve`.
+#'               `lp_solve` and `symphony` are allowed. By default, `lp_solve`. The package `Rsymphony`
+#'               needs to be installed for the option `symphony` to be used.  
 #'
+#' @param integers.solver A character string indicating the linear programming solver to be used to approximate
+#'                        to the closest integer solution, only `symphony` and `lp_solve` are allowed.
+#'                        By default, `symphony`. The package `Rsymphony` needs to be installed for the option `symphony` 
+#'                        to be used. Only used when `integers = TRUE`.
+#'                        
 #' @param ... Other arguments to be passed to the function. Not currently used.
 #' 
 
@@ -55,7 +61,6 @@
 #' mt$VTM.votes
 #' mt$HETe
 #
-#' @importFrom Rsymphony Rsymphony_solve_LP
 #' @importFrom lpSolve lp
 #
 
@@ -63,14 +68,23 @@ tslphom_joint <- function(votes_election1,
                         votes_election2,
                         integers = FALSE,
                         solver = "lp_solve",
+                        integers.solver = "symphony",
                         ...){
   
   argg <- c(as.list(environment()), list(...))
   integers <- test_integers(argg)
   
+  if (integers.solver == "lp_solve"){
+    dec2counts <- dec2counts_lp
+  } else {
+    dec2counts <- dec2counts_symphony
+  }
+  
   # Calculo de la solucion inicial con lphom_joint
-  lphom_inic <- lphom_joint(votes_election1 = votes_election1, votes_election2 = votes_election2,
-                            integers = integers, solver = solver)
+  lphom_inic <- lphom_joint(votes_election1 = votes_election1, 
+                            votes_election2 = votes_election2,
+                            integers = integers, solver = solver,
+                            integers.solver = integers.solver)
 
   # Calculo de las soluciones locales
   VTM.votes_units <- array(NA, c(dim(lphom_inic$VTM.votes), nrow(votes_election1)))
